/*
 * La servlet DataServlet e' l'applicazione server usata dall'applet DataApplet.
 *
 * DataServlet riceve come richiesta un oggetto serializzato con i parametri per generare una tabella quindi crea e invia 
 * come risposta un altro oggetto serializzato con i dati della tabella.
 *
 * Ambiente di sviluppo: Jakarta Tomcat 5.0.27 e Sun JDK 1.4.2
 *
 * @author  Simone Perina
 */
 
package examples.applet2servlet; 

import java.io.*;
import java.util.*;

import javax.servlet.*;
import javax.servlet.http.*;

public class DataServlet extends HttpServlet
{         
	/**
	 * Esegue la richiesta con metodo POST inviata dall'applet DataApplet.
	 *
	 * @param httpServletRequest e' la richiesta HTTP inviata dall'applet DataApplet
	 * @param httpServletResponse e' la risposta HTTP da inviare all'applet DataApplet
	 * @exception <tt>ServletException</tt> in caso di errore nella gestione della richiesta
	 * @exception <tt>IOException</tt> in caso di errore di input/output nella gestione della richiesta
	 */   
	public void doPost(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse) throws ServletException, IOException
   {
      //riceve i parametri di input inviati dall'applet, in caso di errore usa valori di default
      DataInput input;            
      int base, rows, columns;      
      ObjectInputStream inputStream = new ObjectInputStream(httpServletRequest.getInputStream());            
      try
      {
         input = (DataInput)inputStream.readObject();
         base = input.getBase();
         rows = input.getRows();
         columns = input.getColumns();         
      }
      catch(ClassNotFoundException e)
      {
         base = 0;
         rows = 2;
         columns = 3;
      }      
      inputStream.close();      
      
      //elabora la richiesta: imposta le caselle della tabella      
      String[][] items = new String[rows][columns];
	   for (int i = 0; i < rows; i++)
	   {
	      for (int j = 0; j < columns; j++, base++)
	      {
	         items[i][j] = "item" + base;
	      }
	   }	  
	   	   
	   //elabora la richiesta: imposta i nomi delle colonne della tabella      	   
	   String[] names = new String[columns];
	   for (int i = 0; i < columns; i++)
	   {
	      names[i] = "name" + i;
	   }	    
	   
	   //imposta i parametri di output 
	   DataOutput output = new DataOutput();
	   output.setNames(names);
	   output.setItems(items);
	   
	   //invia i parametri di output all'applet
	   httpServletResponse.setContentType("application/x-java-serialized-object");
      ObjectOutputStream outputStream = new ObjectOutputStream(httpServletResponse.getOutputStream());
      outputStream.writeObject(output);
      outputStream.close();
   }   
}