/*
 * La servlet StringServlet e' l'applicazione server usata dall'applet StringApplet.
 *
 * StringServlet riceve come richiesta una stringa di lunghezza variabile quindi crea e invia come risposta una stringa di 
 * lunghezza casuale.
 *
 * Ambiente di sviluppo: Jakarta Tomcat 5.0.27 e Sun JDK 1.4.2
 *
 * @author  Simone Perina
 */
 
package examples.applet2servlet; 

import java.io.*;
import java.util.*;

import javax.servlet.*;
import javax.servlet.http.*;

public class StringServlet extends HttpServlet
{         
   //definisce i limiti per la generazione della stringa di lunghezza casuale
   private static final int MIN_STRING_LENGTH = 100;  
   private static final int MAX_STRING_LENGTH = 1000;  
      
	/**
	 * Esegue la richiesta con metodo POST ricevuta dall'applet StringApplet.
	 *
	 * @param httpServletRequest e' la richiesta HTTP inviata dall'applet StringApplet
	 * @param httpServletResponse e' la risposta HTTP da inviare all'applet StringApplet
	 * @exception <tt>ServletException</tt> in caso di errore nella gestione della richiesta
	 * @exception <tt>IOException</tt> in caso di errore di input/output nella gestione della richiesta
	 */   
	public void doPost(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse) throws ServletException, IOException
   {
      //riceve i parametri di input inviati dall'applet; in questo caso la lunghezza della stringa di input viene
      //recuperata dal valore del campo di intestazione "content-length"
      int contentLength = httpServletRequest.getContentLength();
      byte[] buffer = new byte[contentLength];              
      DataInputStream inputStream = new DataInputStream(httpServletRequest.getInputStream());            
      int bytesRead = inputStream.read(buffer);   
      inputStream.close();      
      
      //ricrea la stringa di input            
      String input = new String(buffer);
      System.out.println("DEBUG: input=" + bytesRead + " bytes");
            	   	 	   
	   //imposta i parametri di output; la lunghezza della stringa viene calcolata usando un numero casuale 
      int length =  (int) (Math.random() * (MAX_STRING_LENGTH - MIN_STRING_LENGTH ) + MIN_STRING_LENGTH);
      StringBuffer stringBuffer = new StringBuffer();
      while (stringBuffer.length() < length) stringBuffer.append("output\n");
      System.out.println("DEBUG: output=" + stringBuffer.length() + " bytes");
      	   
	   //invia i parametri di output all'applet; il contenuto MIME "application/octet-stream" indica un flusso di bytes e
	   //il campo di intestazione "content-length" indica il numero di bytes scritti nel corpo del messaggio
	   httpServletResponse.setContentType("application/octet-stream ");
	   httpServletResponse.setContentLength(stringBuffer.length());
      DataOutputStream outputStream = new DataOutputStream(httpServletResponse.getOutputStream());
      outputStream.write(stringBuffer.toString().getBytes());
      outputStream.close();
   }   
}